==> UniTweaks-0.22.2-sources.jar: net/danygames2014/unitweaks/tweaks/morekeybinds/KeyPressedListener.java <==
package net.danygames2014.unitweaks.tweaks.morekeybinds;

import net.danygames2014.unitweaks.tweaks.photomode.PhotoModeScreen;
import net.danygames2014.unitweaks.tweaks.rawinput.RawInputHandler;
import net.danygames2014.unitweaks.util.Util;
import net.fabricmc.loader.api.FabricLoader;
import net.mine_diver.unsafeevents.listener.EventListener;
import net.minecraft.class_1;
import net.minecraft.class_260;
import net.minecraft.client.Minecraft;
import net.modificationstation.stationapi.api.client.event.keyboard.KeyStateChangedEvent;
import net.modificationstation.stationapi.api.network.packet.PacketHelper;
import org.lwjgl.input.Keyboard;
import org.lwjgl.input.Mouse;

@SuppressWarnings({"unused", "deprecation"})
public class KeyPressedListener {

    static Minecraft minecraft = null;
    public static boolean releasedMouse = false;

    @EventListener
    public void stationKeyPress(KeyStateChangedEvent event){
        keyPress();
    }
    
    public static void keyPress() {
        if (Keyboard.getEventKey() == Keyboard.KEY_NONE) {
            return;
        }

        if (minecraft == null) {
            minecraft = ((Minecraft) FabricLoader.getInstance().getGameInstance());
        }

        if (Keyboard.getEventKeyState()) {
            if (Keyboard.isKeyDown(KeyBindingListener.releaseMouse.field_2381)) {
                if (Mouse.isGrabbed()) {
                    Mouse.setGrabbed(false);
                    releasedMouse = true;
                } else {
                    Mouse.setGrabbed(true);
                    releasedMouse = false;
                }
            }
        }

        if (Keyboard.getEventKeyState() && minecraft.field_2816 == null) {
            // Photo Mode
            if (Keyboard.isKeyDown(KeyBindingListener.photoMode.field_2381)) {
                minecraft.method_2112(new PhotoModeScreen(null));
            }

            // Panorama Screenshot
            if (Keyboard.isKeyDown(KeyBindingListener.panoramaScreenshot.field_2381)) {
                panoramaScreenshot();
            }

            // Dismount
            if (Keyboard.isKeyDown(KeyBindingListener.dismount.field_2381)) {
                dismount();
            }

            // Rescan Mouse
            if (Keyboard.isKeyDown(KeyBindingListener.rescanMouse.field_2381)) {
                RawInputHandler.getMouse("Player Triggered Rescan");
                Util.notify("Rescanning for Mice", true);
            }

            // Toggle Raw Input
            if (Keyboard.isKeyDown(KeyBindingListener.toggleRawInput.field_2381)) {
                RawInputHandler.toggleRawInput();
            }

            // Hotbar Slots
            if (minecraft.field_2816 == null) {
                if (Keyboard.isKeyDown(KeyBindingListener.hotbar1.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 0;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar2.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 1;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar3.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 2;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar4.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 3;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar5.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 4;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar6.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 5;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar7.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 6;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar8.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 7;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar9.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 8;
                }
            }
        }


    }

    public static void dismount() {
        if (minecraft.field_2806 == null) {
            return;
        }

        if (minecraft.field_2806.field_1595 == null) {
            return;
        }

        if (!minecraft.field_2804.field_180) {
            minecraft.field_2806.field_1595.method_1323(minecraft.field_2806);
        } else {
            PacketHelper.send(new class_1(minecraft.field_2806.field_1591, minecraft.field_2806.field_1595.field_1591, 0));
        }
    }

    public static void panoramaScreenshot() {
        // FOV 70 and 2560x1440 -> 2304x1440 scaling works well
        if (minecraft.field_2806 == null) {
            return;
        }

        minecraft.field_2824.field_1481 = true;

        for (int i = 0; i < 6; i++) {
            facePlayer(i);
            minecraft.field_2806.method_1317();
            minecraft.field_2818.method_1844(0F);
            System.out.println(i);
            class_260.method_908(Minecraft.method_2123(), minecraft.field_2802, minecraft.field_2803);
        }

        minecraft.field_2824.field_1481 = false;
    }

    public static void facePlayer(int direction) {
        minecraft.field_2806.field_1600 = Math.floor(minecraft.field_2806.field_1600) + 0.5;
        minecraft.field_2806.field_1602 = Math.floor(minecraft.field_2806.field_1602) + 0.5;
        switch (direction) {
            case 0 -> {
                minecraft.field_2806.field_1607 = 0;
                minecraft.field_2806.field_1606 = 0;
            }
            case 1 -> {
                minecraft.field_2806.field_1607 = 0;
                minecraft.field_2806.field_1606 = 90;
            }
            case 2 -> {
                minecraft.field_2806.field_1607 = 0;
                minecraft.field_2806.field_1606 = 180;
            }
            case 3 -> {
                minecraft.field_2806.field_1607 = 0;
                minecraft.field_2806.field_1606 = 270;
            }
            case 4 -> {
                minecraft.field_2806.field_1607 = 90;
                minecraft.field_2806.field_1606 = 0;
            }
            case 5 -> {
                minecraft.field_2806.field_1607 = -90;
                minecraft.field_2806.field_1606 = 0;
            }
        }
    }
}

==> UniTweaks-0.23.2-sources.jar: net/danygames2014/unitweaks/tweaks/morekeybinds/KeyPressedListener.java <==
package net.danygames2014.unitweaks.tweaks.morekeybinds;

import net.danygames2014.unitweaks.tweaks.photomode.PhotoModeScreen;
import net.danygames2014.unitweaks.tweaks.rawinput.RawInputHandler;
import net.danygames2014.unitweaks.util.Util;
import net.fabricmc.loader.api.FabricLoader;
import net.mine_diver.unsafeevents.listener.EventListener;
import net.minecraft.class_1;
import net.minecraft.class_260;
import net.minecraft.client.Minecraft;
import net.modificationstation.stationapi.api.client.event.keyboard.KeyStateChangedEvent;
import net.modificationstation.stationapi.api.network.packet.PacketHelper;
import org.lwjgl.input.Keyboard;
import org.lwjgl.input.Mouse;

@SuppressWarnings({"unused", "deprecation"})
public class KeyPressedListener {

    static Minecraft minecraft = null;
    public static boolean releasedMouse = false;

    @EventListener
    public void stationKeyPress(KeyStateChangedEvent event){
        keyPress();
    }
    
    public static void keyPress() {
        if (Keyboard.getEventKey() == Keyboard.KEY_NONE) {
            return;
        }

        if (minecraft == null) {
            minecraft = ((Minecraft) FabricLoader.getInstance().getGameInstance());
        }

        if (!Keyboard.getEventKeyState() && minecraft.field_2816 == null) {
            // Release Mouse
            if (Keyboard.getEventKey() == KeyBindingListener.releaseMouse.field_2381) {
                if (Mouse.isGrabbed()) {
                    Mouse.setGrabbed(false);
                    releasedMouse = true;
                } else {
                    Mouse.setGrabbed(true);
                    releasedMouse = false;
                }
            }
        }
        
        if (Keyboard.getEventKeyState() && minecraft.field_2816 == null) {
            // Photo Mode
            if (Keyboard.isKeyDown(KeyBindingListener.photoMode.field_2381)) {
                minecraft.method_2112(new PhotoModeScreen(null));
            }

            // Panorama Screenshot
            if (Keyboard.isKeyDown(KeyBindingListener.panoramaScreenshot.field_2381)) {
                panoramaScreenshot();
            }

            // Dismount
            if (Keyboard.isKeyDown(KeyBindingListener.dismount.field_2381)) {
                dismount();
            }

            // Rescan Mouse
            if (Keyboard.isKeyDown(KeyBindingListener.rescanMouse.field_2381)) {
                RawInputHandler.getMouse("Player Triggered Rescan");
                Util.notify("Rescanning for Mice", true);
            }

            // Toggle Raw Input
            if (Keyboard.isKeyDown(KeyBindingListener.toggleRawInput.field_2381)) {
                RawInputHandler.toggleRawInput();
            }

            // Hotbar Slots
            if (minecraft.field_2816 == null) {
                if (Keyboard.isKeyDown(KeyBindingListener.hotbar1.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 0;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar2.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 1;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar3.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 2;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar4.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 3;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar5.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 4;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar6.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 5;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar7.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 6;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar8.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 7;
                } else if (Keyboard.isKeyDown(KeyBindingListener.hotbar9.field_2381)) {
                    minecraft.field_2806.field_519.field_747 = 8;
                }
            }
        }


    }

    public static void dismount() {
        if (minecraft.field_2806 == null) {
            return;
        }

        if (minecraft.field_2806.field_1595 == null) {
            return;
        }

        if (!minecraft.field_2804.field_180) {
            minecraft.field_2806.field_1595.method_1323(minecraft.field_2806);
        } else {
            PacketHelper.send(new class_1(minecraft.field_2806.field_1591, minecraft.field_2806.field_1595.field_1591, 0));
        }
    }

    public static void panoramaScreenshot() {
        // FOV 70 and 2560x1440 -> 2304x1440 scaling works well
        if (minecraft.field_2806 == null) {
            return;
        }

        minecraft.field_2824.field_1481 = true;

        for (int i = 0; i < 6; i++) {
            facePlayer(i);
            minecraft.field_2806.method_1317();
            minecraft.field_2818.method_1844(0F);
            System.out.println(i);
            class_260.method_908(Minecraft.method_2123(), minecraft.field_2802, minecraft.field_2803);
        }

        minecraft.field_2824.field_1481 = false;
    }

    public static void facePlayer(int direction) {
        minecraft.field_2806.field_1600 = Math.floor(minecraft.field_2806.field_1600) + 0.5;
        minecraft.field_2806.field_1602 = Math.floor(minecraft.field_2806.field_1602) + 0.5;
        switch (direction) {
            case 0 -> {
                minecraft.field_2806.field_1607 = 0;
                minecraft.field_2806.field_1606 = 0;
            }
            case 1 -> {
                minecraft.field_2806.field_1607 = 0;
                minecraft.field_2806.field_1606 = 90;
            }
            case 2 -> {
                minecraft.field_2806.field_1607 = 0;
                minecraft.field_2806.field_1606 = 180;
            }
            case 3 -> {
                minecraft.field_2806.field_1607 = 0;
                minecraft.field_2806.field_1606 = 270;
            }
            case 4 -> {
                minecraft.field_2806.field_1607 = 90;
                minecraft.field_2806.field_1606 = 0;
            }
            case 5 -> {
                minecraft.field_2806.field_1607 = -90;
                minecraft.field_2806.field_1606 = 0;
            }
        }
    }
}
